#*******************************************************************************
#* Licensed Materials - Property of IBM                                        *
#* 5698-A17                                                                    *
#* (C) Copyright IBM Corp. 2006 All Rights Reserved.                     *
#* US Government Users Restricted Rights - Use, duplication or                 *
#* disclosure restricted by GSA ADP Schedule Contract with                     *
#* IBM Corp.                                                                   *
#*******************************************************************************
###	The parameters this script needs are distinguished using couples of
###	keywords. The first value is the option that is a constant identifying the
###	parameter, the second value is its argument that the script uses.
###	Here follows the list of all the option keyword: 
###
###	-d     (mandatory)	it identifies the Universal Agent installation directory
###
###	-h     (mandatory)    	the TWS for z/OS Controller hostname for the socket data 
###                           provider
###	
###	-t     (optional)		it identifies the value in seconds to provide in the TTL 
###                           parameter for the NAME statement. Default value is 86400
###
###	The couples option-argument can be passed in the order you want. 
###	This script executes checks about the presence of the mandatory options, 
###	unknown options, and some validation checks are made on the argument values

###   Variable SetUp

ERR_RC=0
arg_count=$#
keyword1="-d"
keyword2="-h"
keyword3="-t"
usage="?"
UAInstDir=""
hostname=""
UA_TTL=0
moreHostnames=1
one_shift_done=0
sock_statement="\/\/SOURCE SOCK"
setsource="SETSOURCENAME=Y"
name_job="\/\/NAME\ JOB\ K\ "
name_jobstream="\/\/NAME\ JOBSTREAM\ K\ "
name_alert="\/\/NAME\ ALERT\ E\ "
name_critical="\/\/NAME\ CRITICAL\ K\ "
sock_line=""
sed_line1="s/^\/\/SOURCE.*/"
sed_line2="s/\/\/NAME\ JOB\ K\ 86400/"
sed_line3="s/\/\/NAME\ JOBSTREAM\ K\ 86400/"
sed_line4="s/\/\/NAME\ ALERT\ E\ 86400/"
sed_line5="s/\/\/NAME\ CRITICAL\ K\ 86400/"

first_sock=0
write_line=""
must_write=0
lastline_written=0
mand_opt1=0
mand_opt2=0
meta_path=""
key1_repeat=0
key2_repeat=0
key3_repeat=0

### define messages and check subroutines

usage_msg()
{
	echo "USAGE:"
	echo "tepconfig -d Universal Agent install_dir -h hostname... [-t time to live for TWSz monitored data]"
	exit $ERR_RC
}

remove_temp_files()
{
	if [ -f metafile.sed ]
	then 
		rm metafile.sed
	fi
}

issue_succ_msg()
{
echo "The TEP configuration was successfully completed with the following values:"
echo "Universal Agent installation directory: $UAInstDir"
echo "hostname (last): $hostname"
if [ $UA_TTL -gt 0 ]
then 
	echo "Universal Agent time to live: $UA_TTL"
fi
}

err_msg_more_than_1()
{
 echo "the option $@ has been specified more than one time"
 err_end_msg "$ERR_RC"
 exit $ERR_RC
}

err_msg_no_metafile()
{
	echo "the sample metafile was not found"
	err_end_msg "$ERR_RC"
	exit $ERR_RC
}

err_msg_unknown_opt()
{
	echo "the option $@ is unknown"
	err_end_msg "$ERR_RC"
	exit $ERR_RC
}

err_msg_incorrect_value_opt()
{
	echo "the value specified $@ is not valid"
	err_end_msg "$ERR_RC"
	exit $ERR_RC
}

err_msg_mandatory_lack()
{
	echo "the mandatory option $@ is missing"
}

err_msg_exit()
{
	err_end_msg "$ERR_RC"
	exit $ERR_RC
}

err_end_msg  ()
{
	echo "NO ACTION WAS TAKEN, EXITING WITH RC=$@"
	remove_temp_files
}

### verify if usage message should be used

if [ $# -eq 0 ]
then 
	usage_msg
fi

### if no sample meta file issue error message

if [ ! -f TWSz851SampleMeta.mdl ]
then
	err_msg_no_metafile
fi

### parse arguments

while [ $# -gt 0 ]
do
	case $1
	in
		"$usage")
				usage_msg
				;;

		"$keyword1")
				if [ $key1_repeat -gt 0 ]
				then
					ERR_RC=8
					err_msg_more_than_1 "$1"
				fi
			
				if [ $# -gt 1 ]
				then
					UAInstDir=$2

					if [ ! -f "$UAInstDir"/bin/um_console ]
					then
						ERR_RC=8
			     			err_msg_incorrect_value_opt "$2"
					fi
				else
					ERR_RC=8
			     		err_msg_incorrect_value_opt "$2"
			     	fi
			     	
				mand_opt1=1
				key1_repeat=1
				;;
		
		"$keyword2")
				if [ $key2_repeat -gt 0 ]
				then
					ERR_RC=8
					err_msg_more_than_1 "$1"
				fi

				if [ $# -eq 1 ]
				then
					ERR_RC=8
			     		err_msg_incorrect_value_opt "$2"
			     	fi
				
				key2_repeat=1
				
				while [ $moreHostnames -gt 0 ]
				do
			     		case $2			
					in
						"$keyword1") newkey=0;;
						"$keyword2") newkey=0;;
						"$keyword3") newkey=0;;
						*)           newkey=1;;
					esac
					
					if [ $newkey -eq 1 ]
					then
						hostname="$2"
						sock_line="${sock_statement} ${hostname} ${setsource}"
						must_write=1
						mand_opt2=1						

						if [ $# -gt 2 ]
						then 
							shift
							one_shift_done=1
							
							case $2			
							in
								"$keyword1") moreHostnames=0;;
								"$keyword2") moreHostnames=0;;
								"$keyword3") moreHostnames=0;;
								*)           moreHostnames=1;;
							esac

						else
							moreHostnames=0
							if [ $first_sock -eq 1 ]
							then 
								shift
							fi
						fi
						
						
					else
						moreHostnames=0

						### if no value specified after -h
						if [ $must_write -eq 0 ]
						then
							ERR_RC=8
			     				err_msg_incorrect_value_opt "$2"
						fi
 
					fi

  		      		if [ $must_write -gt 0 ]
		      		then 
			     			if [ $first_sock -eq 0 ]
			     			then
							### if we get here it's first line of multiple
							### host names
							if [ $moreHostnames -eq 1 ]
							then
			     					write_line="${sed_line1}${sock_line}\\"
							### here is first and last host name with other
							### keywords following
							else
								write_line="${sed_line1}${sock_line}/"
								lastline_written=1
							fi
							
							first_sock=1
							echo $write_line > metafile.sed
			     			else
							### if we get here it's next line of multiple
							### host names
							if [ $moreHostnames -eq 1 ]
							then
				     				write_line="${sock_line}\\"
							### here is last line of multiple host names
							else
				     				write_line="${sock_line}/"
				     				lastline_written=1
							fi

							echo $write_line >> metafile.sed
					     	fi
					fi						
						
				
				done
				
				;;
				
		"$keyword3")
				if [ $key3_repeat -gt 0 ]
				then
					ERR_RC=8
					err_msg_more_than_1 "$1"
				fi
				key3_repeat=1
				
				if [ $# -gt 1 ]
				then
					UA_TTL=$2
				else
					ERR_RC=8
			     		err_msg_incorrect_value_opt "$2"
			     	fi

			      if [ $UA_TTL -gt 0 ]
			      then
					write_line=""
			     	     	write_line="${sed_line2}${name_job}${UA_TTL}/"
			      	echo $write_line >> metafile.sed
			        
			        	write_line="${sed_line3}${name_jobstream}${UA_TTL}/"
			        	echo $write_line >> metafile.sed
			     
			        	write_line="${sed_line4}${name_alert}${UA_TTL}/"
			        	echo $write_line >> metafile.sed

					write_line="${sed_line5}${name_critical}${UA_TTL}/"
					echo $write_line >> metafile.sed

			      else
					ERR_RC=8
			     		err_msg_incorrect_value_opt "$UA_TTL"
			      fi
				;;
 

		*)
				ERR_RC=8 	    	
				err_msg_unknown_opt "$1"
	esac

	if [ $# -gt 0 ]
	then
		if [ $one_shift_done -gt 0 ]
		then
			shift
			one_shift_done=0
		else
			shift
			shift
		fi
	fi
	
done

if [ $mand_opt1 -eq 0 ]
then
	ERR_RC=8
	err_msg_mandatory_lack "$keyword1"
fi

if [ $mand_opt2 -eq 0 ]
then
	ERR_RC=8
	err_msg_mandatory_lack "$keyword2"
fi

if [ $mand_opt1 -eq 0 ] || [ $mand_opt2 -eq 0 ]
then
	err_msg_exit
fi

### if we get here mandatory parm were present: create metafile and install it

sed -f metafile.sed TWSz851SampleMeta.mdl > TWSz851Meta.mdl


KUMP_DPCONSOLE_NOCONFIRM=Y
	
export KUMP_DPCONSOLE_NOCONFIRM 

meta_path=$PWD

"$UAInstDir"/bin/um_console -h "$UAInstDir" -c "import "$meta_path"/TWSz851Meta.mdl"

if [ $? -eq 255 ] 
then
	"$UAInstDir"/bin/um_console -h "$UAInstDir" -c "refresh "$meta_path"/TWSz851Meta.mdl"
fi

### issue successful completion message

if [ $? -eq 0 ] 
then
	issue_succ_msg
fi

remove_temp_files
